@@ -10,8 +10,9 @@ OC.L10N.register(
     "Confirm" : "Konfirmi",
     "Date:" : "Dato:",
     "Where:" : "Kie:",
+    "Anniversary" : "Datreveno",
+    "Personal" : "Persona",
     "A Calendar app for Nextcloud" : "Aplikaĵo pri kalendaro por Nextcloud",
-    "New event" : "Nova okazaĵo",
     "Today" : "Hodiaŭ",
     "Day" : "Tago",
     "Week" : "Semajno",
@@ -28,12 +29,13 @@ OC.L10N.register(
     "Deleted" : "Forigita",
     "Restore" : "Restaŭri",
     "Delete permanently" : "Forigi por ĉiam",
+    "Internal link" : "Interna ligilo",
     "Share link" : "Kunhavigi ligilon",
     "Delete share link" : "Forigi kunhavo-ligilon",
     "can edit" : "povas redakti",
     "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
     "No users or groups" : "Neniu uzanto aŭ grupo",
-    "Copy private link" : "Kopii privatan ligilon",
+    "Save" : "Konservi",
     "Filename" : "Dosiernomo",
     "Cancel" : "Nuligi",
     "Automatic" : "Aŭtomata",
@@ -51,9 +53,9 @@ OC.L10N.register(
     "Friday" : "vendredo",
     "Saturday" : "sabato",
     "Sunday" : "dimanĉo",
-    "Save" : "Konservi",
     "Update" : "Ĝisdatigi",
     "Your email address" : "Via retpoŝta adreso",
+    "Notification" : "Atentigo",
     "Email" : "Retpoŝto",
     "Delete file" : "Forigi dosieron",
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
@@ -70,7 +72,7 @@ OC.L10N.register(
     "after" : "post",
     "More" : "Pli",
     "Global" : "Monda",
-    "Personal" : "Persona",
+    "Subscribe" : "Aboni",
     "[Today]" : "[Hodiaŭ]",
     "[Tomorrow]" : "[Morgaŭ]",
     "[Yesterday]" : "[Hieraŭ]",
@@ -78,12 +80,10 @@ OC.L10N.register(
     "Attendees" : "Ĉeestontoj",
     "Resources" : "Rimedoj",
     "Close" : "Fermi",
-    "Anniversary" : "Datreveno",
     "Week {number} of {year}" : "Semajno {number} en {year}",
     "Daily" : "Ĉiutage",
     "Weekly" : "Ĉiusemajne",
     "Untitled event" : "Sentitola okazaĵo",
-    "Next" : "Sekva",
     "Other" : "Alia",
     "When shared show full event" : "Kiam kunhavigita, montri plenajn detalojn",
     "When shared show only busy" : "Kiam kunhavigita, montri nur kiel okupita",
