@@ -9,13 +9,16 @@ OC.L10N.register(
     "Calendar" : "Kalender",
     "Confirm" : "Kinnita",
     "Where:" : "Kus:",
+    "Anniversary" : "Aastapäev",
+    "Appointment" : "Kohtumine",
+    "Personal" : "Isiklik",
+    "Vacation" : "Puhkus",
     "Previous day" : "Eelmine päev",
     "Previous week" : "Eelmine nädal",
     "Previous month" : "Eelmine kuu",
     "Next day" : "Järgmine päev",
     "Next week" : "Järgmine nädal",
     "Next month" : "Järgmine kuu",
-    "New event" : "Uus sündmus",
     "Today" : "Täna",
     "Day" : "Päev",
     "Week" : "Nädal",
@@ -31,6 +34,7 @@ OC.L10N.register(
     "Deleted" : "Kustutatud",
     "Restore" : "Taasta",
     "Delete permanently" : "Kustuta jäädavalt",
+    "Empty trash bin" : "Tühjenda prügikast",
     "Internal link" : "Sisemine link",
     "Share link" : "Jaga link",
     "Copy public link" : "Kopeeri avalik link",
@@ -43,6 +47,7 @@ OC.L10N.register(
     "Import calendars" : "Impordi kalendrid",
     "Filename" : "Faili nimi",
     "Cancel" : "Loobu",
+    "Invalid location selected" : "Vigane asukoht valitud",
     "Automatic" : "Automaatne",
     "List view" : "Nimekirjavaade",
     "Actions" : "Tegevused",
@@ -77,14 +82,10 @@ OC.L10N.register(
     "More" : "Rohkem",
     "Global" : "Üldine",
     "Subscribe" : "Telli",
-    "Personal" : "Isiklik",
     "Details" : "Üksikasjad",
     "Attendees" : "Osalejad",
     "Resources" : "Ressursid",
     "Close" : "Sulge",
-    "Anniversary" : "Aastapäev",
-    "Appointment" : "Kohtumine",
-    "Vacation" : "Puhkus",
     "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
     "Does not repeat" : "Ei kordu",
     "Daily" : "Iga päev",
