@@ -8,11 +8,12 @@ OC.L10N.register(
     "Cheers!" : "Tudelu!",
     "Calendar" : "Kalender",
     "Prepare for %s" : "Klargjer for %s",
-    "New event" : "Ny hending",
+    "Personal" : "Personleg",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Veke",
     "Month" : "Månad",
+    "Year" : "År",
     "Copy link" : "Kopier lenkje",
     "Edit" : "Rediger",
     "Delete" : "Slett",
@@ -25,6 +26,7 @@ OC.L10N.register(
     "Empty trash bin" : "Tøm søppel korg",
     "Share link" : "Del lenkje",
     "can edit" : "kan endra",
+    "Save" : "Lagre",
     "Cancel" : "Avbryt",
     "List view" : "Liste visning",
     "Actions" : "Handlingar",
@@ -39,7 +41,6 @@ OC.L10N.register(
     "Friday" : "Fredag",
     "Saturday" : "Laurdag",
     "Sunday" : "Søndag",
-    "Save" : "Lagre",
     "Update" : "Oppdater",
     "Your email address" : "Di epost-adresse",
     "Email" : "E-post",
@@ -54,14 +55,11 @@ OC.L10N.register(
     "Room type" : "Romtype",
     "More" : "Meir",
     "Global" : "Global",
-    "Personal" : "Personleg",
     "Details" : "Detaljar",
     "Attendees" : "Deltakarar",
     "Close" : "Lukk",
     "Daily" : "Kvar dag",
     "Weekly" : "Kvar veke",
-    "Next" : "Neste",
-    "Year" : "År",
     "Meeting room" : "Møterom",
     "Other" : "Anna",
     "When shared show full event" : "Når delt, vis heile hendinga",
