@@ -1,16 +1,17 @@
 OC.L10N.register(
     "calendar",
     {
-    "Provided email-address is not valid" : "ผู้ให้บริการอีเมลไม่ถูกต้อง",
-    "%s has published the calendar »%s«" : "%s ได้เผยแพร่ปฏิทิน %s",
-    "Unexpected error sending email. Please contact your administrator." : "เกิดข้อผิดพลาดไม่คาดคิดขณะส่งอีเมล โปรดติดต่อผู้ดูแล",
+    "Provided email-address is not valid" : "ที่อยู่อีเมลที่ระบุไว้ไม่ถูกต้อง",
+    "%s has published the calendar »%s«" : "%s ได้เผยแพร่ปฏิทิน »%s«",
+    "Unexpected error sending email. Please contact your administrator." : "เกิดข้อผิดพลาดไม่คาดคิดขณะส่งอีเมล โปรดติดต่อผู้ดูแลระบบของคุณ",
     "Successfully sent email to %1$s" : "ส่งอีเมลถึง %1$s สำเร็จ",
     "Hello," : "สวัสดี",
     "Open »%s«" : "เปิด »%s«",
     "Cheers!" : "ไชโย!",
-    "Confirm" : "ยืนยัน",
     "Calendar" : "ปฏิทิน",
-    "New event" : "เหตุการณ์ใหม่",
+    "Confirm" : "ยืนยัน",
+    "Anniversary" : "วันครบรอบ",
+    "Personal" : "ส่วนตัว",
     "Today" : "วันนี้",
     "Day" : "วัน",
     "Week" : "สัปดาห์",
@@ -26,16 +27,17 @@ OC.L10N.register(
     "Restore" : "คืนค่า",
     "Delete permanently" : "ลบแบบถาวร",
     "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
-    "Share link" : "แชร์ลิงค์",
+    "Share link" : "แชร์ลิงก์",
     "can edit" : "สามารถแก้ไข",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
+    "Save" : "บันทึก",
     "Filename" : "ชื่อไฟล์",
     "Cancel" : "ยกเลิก",
     "Automatic" : "อัตโนมัติ",
     "List view" : "มุมมองแบบรายการ",
     "Actions" : "การกระทำ",
-    "Location" : "ตำแหน่งที่อยู่",
-    "Description" : "รายละเอียด",
+    "Location" : "ตำแหน่ง",
+    "Description" : "คำอธิบาย",
     "to" : "ถึง",
     "Add" : "เพิ่ม",
     "Monday" : "วันจันทร์",
@@ -45,10 +47,11 @@ OC.L10N.register(
     "Friday" : "วันศุกร์",
     "Saturday" : "วันเสาร์",
     "Sunday" : "วันอาทิตย์",
-    "Save" : "บันทึก",
-    "Update" : "อัพเดท",
+    "Update" : "อัปเดต",
     "Your email address" : "ที่อยู่อีเมลของคุณ",
     "Email" : "อีเมล",
+    "Delete file" : "ลบไฟล์",
+    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Unknown" : "ไม่ทราบ",
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
@@ -56,25 +59,23 @@ OC.L10N.register(
     "Send email" : "ส่งอีเมล",
     "Repeat" : "ทำซ้ำ",
     "never" : "ไม่ต้องเลย",
-    "after" : "หลัง",
+    "after" : "หลังจาก",
     "More" : "เพิ่มเติม",
     "Pick a date" : "เลือกวันที่",
     "Global" : "ทั่วไป",
-    "Personal" : "ส่วนตัว",
+    "Subscribe" : "สมัครรับข้อมูล",
     "Details" : "รายละเอียด",
     "Attendees" : "ผู้เข้าร่วมกิจกรรม",
     "Close" : "ปิด",
-    "Anniversary" : "วันครบรอบ",
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
-    "Daily" : "รุ่นรายวัน",
+    "Daily" : "รายวัน",
     "Weekly" : "รายสัปดาห์",
-    "Next" : "ถัดไป",
     "Other" : "อื่น ๆ",
-    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
+    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
     "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
     "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
     "Status" : "สถานะ",
-    "Confirmed" : "ได้รับการยืนยันแล้ว",
+    "Confirmed" : "ยืนยันแล้ว",
     "Categories" : "หมวดหมู่",
     "Commuting" : "กำลังเดินทาง",
     "Presentation" : "งานนำเสนอ",
